@@ -33,6 +33,6 @@ def make_dataset(dataset="common_gen", split="train"):
     else:
         dataset = load_dataset(dataset, split=split)
         print(dataset)
-        df = make_keywords(df)
+        df = make_keywords(dataset=dataset)
         return df
   
\ No newline at end of file
